/*
 * Generated by gdbus-codegen 2.43.4. DO NOT EDIT.
 *
 * The license of this code is the same as for the source it was derived from.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "gsd-session-manager-glue.h"

#include <string.h>
#ifdef G_OS_UNIX
#  include <gio/gunixfdlist.h>
#endif

typedef struct
{
  GDBusArgInfo parent_struct;
  gboolean use_gvariant;
} _ExtendedGDBusArgInfo;

typedef struct
{
  GDBusMethodInfo parent_struct;
  const gchar *signal_name;
  gboolean pass_fdlist;
} _ExtendedGDBusMethodInfo;

typedef struct
{
  GDBusSignalInfo parent_struct;
  const gchar *signal_name;
} _ExtendedGDBusSignalInfo;

typedef struct
{
  GDBusPropertyInfo parent_struct;
  const gchar *hyphen_name;
  gboolean use_gvariant;
} _ExtendedGDBusPropertyInfo;

typedef struct
{
  GDBusInterfaceInfo parent_struct;
  const gchar *hyphen_name;
} _ExtendedGDBusInterfaceInfo;

typedef struct
{
  const _ExtendedGDBusPropertyInfo *info;
  guint prop_id;
  GValue orig_value; /* the value before the change */
} ChangedProperty;

static void
_changed_property_free (ChangedProperty *data)
{
  g_value_unset (&data->orig_value);
  g_free (data);
}

static gboolean
_g_strv_equal0 (gchar **a, gchar **b)
{
  gboolean ret = FALSE;
  guint n;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  if (g_strv_length (a) != g_strv_length (b))
    goto out;
  for (n = 0; a[n] != NULL; n++)
    if (g_strcmp0 (a[n], b[n]) != 0)
      goto out;
  ret = TRUE;
out:
  return ret;
}

static gboolean
_g_variant_equal0 (GVariant *a, GVariant *b)
{
  gboolean ret = FALSE;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  ret = g_variant_equal (a, b);
out:
  return ret;
}

G_GNUC_UNUSED static gboolean
_g_value_equal (const GValue *a, const GValue *b)
{
  gboolean ret = FALSE;
  g_assert (G_VALUE_TYPE (a) == G_VALUE_TYPE (b));
  switch (G_VALUE_TYPE (a))
    {
      case G_TYPE_BOOLEAN:
        ret = (g_value_get_boolean (a) == g_value_get_boolean (b));
        break;
      case G_TYPE_UCHAR:
        ret = (g_value_get_uchar (a) == g_value_get_uchar (b));
        break;
      case G_TYPE_INT:
        ret = (g_value_get_int (a) == g_value_get_int (b));
        break;
      case G_TYPE_UINT:
        ret = (g_value_get_uint (a) == g_value_get_uint (b));
        break;
      case G_TYPE_INT64:
        ret = (g_value_get_int64 (a) == g_value_get_int64 (b));
        break;
      case G_TYPE_UINT64:
        ret = (g_value_get_uint64 (a) == g_value_get_uint64 (b));
        break;
      case G_TYPE_DOUBLE:
        {
          /* Avoid -Wfloat-equal warnings by doing a direct bit compare */
          gdouble da = g_value_get_double (a);
          gdouble db = g_value_get_double (b);
          ret = memcmp (&da, &db, sizeof (gdouble)) == 0;
        }
        break;
      case G_TYPE_STRING:
        ret = (g_strcmp0 (g_value_get_string (a), g_value_get_string (b)) == 0);
        break;
      case G_TYPE_VARIANT:
        ret = _g_variant_equal0 (g_value_get_variant (a), g_value_get_variant (b));
        break;
      default:
        if (G_VALUE_TYPE (a) == G_TYPE_STRV)
          ret = _g_strv_equal0 (g_value_get_boxed (a), g_value_get_boxed (b));
        else
          g_critical ("_g_value_equal() does not handle type %s", g_type_name (G_VALUE_TYPE (a)));
        break;
    }
  return ret;
}

/* ------------------------------------------------------------------------
 * Code for interface org.gnome.SessionManager
 * ------------------------------------------------------------------------
 */

/**
 * SECTION:GsdSessionManager
 * @title: GsdSessionManager
 * @short_description: Generated C code for the org.gnome.SessionManager D-Bus interface
 *
 * This section contains code for working with the <link linkend="gdbus-interface-org-gnome-SessionManager.top_of_page">org.gnome.SessionManager</link> D-Bus interface in C.
 */

/* ---- Introspection data for org.gnome.SessionManager ---- */

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_setenv_IN_ARG_variable =
{
  {
    -1,
    (gchar *) "variable",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_setenv_IN_ARG_value =
{
  {
    -1,
    (gchar *) "value",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_setenv_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_setenv_IN_ARG_variable,
  &_gsd_session_manager_method_info_setenv_IN_ARG_value,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_setenv =
{
  {
    -1,
    (gchar *) "Setenv",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_setenv_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-setenv",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_get_locale_IN_ARG_category =
{
  {
    -1,
    (gchar *) "category",
    (gchar *) "i",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_get_locale_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_get_locale_IN_ARG_category,
  NULL
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_get_locale_OUT_ARG_value =
{
  {
    -1,
    (gchar *) "value",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_get_locale_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_get_locale_OUT_ARG_value,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_get_locale =
{
  {
    -1,
    (gchar *) "GetLocale",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_get_locale_IN_ARG_pointers,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_get_locale_OUT_ARG_pointers,
    NULL
  },
  "handle-get-locale",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_initialization_error_IN_ARG_message =
{
  {
    -1,
    (gchar *) "message",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_initialization_error_IN_ARG_fatal =
{
  {
    -1,
    (gchar *) "fatal",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_initialization_error_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_initialization_error_IN_ARG_message,
  &_gsd_session_manager_method_info_initialization_error_IN_ARG_fatal,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_initialization_error =
{
  {
    -1,
    (gchar *) "InitializationError",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_initialization_error_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-initialization-error",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_register_client_IN_ARG_app_id =
{
  {
    -1,
    (gchar *) "app_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_register_client_IN_ARG_client_startup_id =
{
  {
    -1,
    (gchar *) "client_startup_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_register_client_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_register_client_IN_ARG_app_id,
  &_gsd_session_manager_method_info_register_client_IN_ARG_client_startup_id,
  NULL
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_register_client_OUT_ARG_client_id =
{
  {
    -1,
    (gchar *) "client_id",
    (gchar *) "o",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_register_client_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_register_client_OUT_ARG_client_id,
  NULL
};

static const GDBusAnnotationInfo _gsd_session_manager_method_register_client_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.GLib.Async",
  (gchar *) "",
  NULL
};

static const GDBusAnnotationInfo * const _gsd_session_manager_method_register_client_annotation_info_pointers[] =
{
  &_gsd_session_manager_method_register_client_annotation_info_0,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_register_client =
{
  {
    -1,
    (gchar *) "RegisterClient",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_register_client_IN_ARG_pointers,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_register_client_OUT_ARG_pointers,
    (GDBusAnnotationInfo **) &_gsd_session_manager_method_register_client_annotation_info_pointers
  },
  "handle-register-client",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_unregister_client_IN_ARG_client_id =
{
  {
    -1,
    (gchar *) "client_id",
    (gchar *) "o",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_unregister_client_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_unregister_client_IN_ARG_client_id,
  NULL
};

static const GDBusAnnotationInfo _gsd_session_manager_method_unregister_client_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.GLib.Async",
  (gchar *) "",
  NULL
};

static const GDBusAnnotationInfo * const _gsd_session_manager_method_unregister_client_annotation_info_pointers[] =
{
  &_gsd_session_manager_method_unregister_client_annotation_info_0,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_unregister_client =
{
  {
    -1,
    (gchar *) "UnregisterClient",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_unregister_client_IN_ARG_pointers,
    NULL,
    (GDBusAnnotationInfo **) &_gsd_session_manager_method_unregister_client_annotation_info_pointers
  },
  "handle-unregister-client",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_inhibit_IN_ARG_app_id =
{
  {
    -1,
    (gchar *) "app_id",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_inhibit_IN_ARG_toplevel_xid =
{
  {
    -1,
    (gchar *) "toplevel_xid",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_inhibit_IN_ARG_reason =
{
  {
    -1,
    (gchar *) "reason",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_inhibit_IN_ARG_flags =
{
  {
    -1,
    (gchar *) "flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_inhibit_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_inhibit_IN_ARG_app_id,
  &_gsd_session_manager_method_info_inhibit_IN_ARG_toplevel_xid,
  &_gsd_session_manager_method_info_inhibit_IN_ARG_reason,
  &_gsd_session_manager_method_info_inhibit_IN_ARG_flags,
  NULL
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_inhibit_OUT_ARG_inhibit_cookie =
{
  {
    -1,
    (gchar *) "inhibit_cookie",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_inhibit_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_inhibit_OUT_ARG_inhibit_cookie,
  NULL
};

static const GDBusAnnotationInfo _gsd_session_manager_method_inhibit_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.GLib.Async",
  (gchar *) "",
  NULL
};

static const GDBusAnnotationInfo * const _gsd_session_manager_method_inhibit_annotation_info_pointers[] =
{
  &_gsd_session_manager_method_inhibit_annotation_info_0,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_inhibit =
{
  {
    -1,
    (gchar *) "Inhibit",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_inhibit_IN_ARG_pointers,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_inhibit_OUT_ARG_pointers,
    (GDBusAnnotationInfo **) &_gsd_session_manager_method_inhibit_annotation_info_pointers
  },
  "handle-inhibit",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_uninhibit_IN_ARG_inhibit_cookie =
{
  {
    -1,
    (gchar *) "inhibit_cookie",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_uninhibit_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_uninhibit_IN_ARG_inhibit_cookie,
  NULL
};

static const GDBusAnnotationInfo _gsd_session_manager_method_uninhibit_annotation_info_0 =
{
  -1,
  (gchar *) "org.freedesktop.DBus.GLib.Async",
  (gchar *) "",
  NULL
};

static const GDBusAnnotationInfo * const _gsd_session_manager_method_uninhibit_annotation_info_pointers[] =
{
  &_gsd_session_manager_method_uninhibit_annotation_info_0,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_uninhibit =
{
  {
    -1,
    (gchar *) "Uninhibit",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_uninhibit_IN_ARG_pointers,
    NULL,
    (GDBusAnnotationInfo **) &_gsd_session_manager_method_uninhibit_annotation_info_pointers
  },
  "handle-uninhibit",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_is_inhibited_IN_ARG_flags =
{
  {
    -1,
    (gchar *) "flags",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_is_inhibited_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_is_inhibited_IN_ARG_flags,
  NULL
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_is_inhibited_OUT_ARG_is_inhibited =
{
  {
    -1,
    (gchar *) "is_inhibited",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_is_inhibited_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_is_inhibited_OUT_ARG_is_inhibited,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_is_inhibited =
{
  {
    -1,
    (gchar *) "IsInhibited",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_is_inhibited_IN_ARG_pointers,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_is_inhibited_OUT_ARG_pointers,
    NULL
  },
  "handle-is-inhibited",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_get_clients_OUT_ARG_clients =
{
  {
    -1,
    (gchar *) "clients",
    (gchar *) "ao",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_get_clients_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_get_clients_OUT_ARG_clients,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_get_clients =
{
  {
    -1,
    (gchar *) "GetClients",
    NULL,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_get_clients_OUT_ARG_pointers,
    NULL
  },
  "handle-get-clients",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_get_inhibitors_OUT_ARG_inhibitors =
{
  {
    -1,
    (gchar *) "inhibitors",
    (gchar *) "ao",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_get_inhibitors_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_get_inhibitors_OUT_ARG_inhibitors,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_get_inhibitors =
{
  {
    -1,
    (gchar *) "GetInhibitors",
    NULL,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_get_inhibitors_OUT_ARG_pointers,
    NULL
  },
  "handle-get-inhibitors",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_is_autostart_condition_handled_IN_ARG_condition =
{
  {
    -1,
    (gchar *) "condition",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_is_autostart_condition_handled_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_is_autostart_condition_handled_IN_ARG_condition,
  NULL
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_is_autostart_condition_handled_OUT_ARG_handled =
{
  {
    -1,
    (gchar *) "handled",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_is_autostart_condition_handled_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_is_autostart_condition_handled_OUT_ARG_handled,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_is_autostart_condition_handled =
{
  {
    -1,
    (gchar *) "IsAutostartConditionHandled",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_is_autostart_condition_handled_IN_ARG_pointers,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_is_autostart_condition_handled_OUT_ARG_pointers,
    NULL
  },
  "handle-is-autostart-condition-handled",
  FALSE
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_shutdown =
{
  {
    -1,
    (gchar *) "Shutdown",
    NULL,
    NULL,
    NULL
  },
  "handle-shutdown",
  FALSE
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_reboot =
{
  {
    -1,
    (gchar *) "Reboot",
    NULL,
    NULL,
    NULL
  },
  "handle-reboot",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_can_shutdown_OUT_ARG_is_available =
{
  {
    -1,
    (gchar *) "is_available",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_can_shutdown_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_can_shutdown_OUT_ARG_is_available,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_can_shutdown =
{
  {
    -1,
    (gchar *) "CanShutdown",
    NULL,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_can_shutdown_OUT_ARG_pointers,
    NULL
  },
  "handle-can-shutdown",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_logout_IN_ARG_mode =
{
  {
    -1,
    (gchar *) "mode",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_logout_IN_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_logout_IN_ARG_mode,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_logout =
{
  {
    -1,
    (gchar *) "Logout",
    (GDBusArgInfo **) &_gsd_session_manager_method_info_logout_IN_ARG_pointers,
    NULL,
    NULL
  },
  "handle-logout",
  FALSE
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_method_info_is_session_running_OUT_ARG_running =
{
  {
    -1,
    (gchar *) "running",
    (gchar *) "b",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_method_info_is_session_running_OUT_ARG_pointers[] =
{
  &_gsd_session_manager_method_info_is_session_running_OUT_ARG_running,
  NULL
};

static const _ExtendedGDBusMethodInfo _gsd_session_manager_method_info_is_session_running =
{
  {
    -1,
    (gchar *) "IsSessionRunning",
    NULL,
    (GDBusArgInfo **) &_gsd_session_manager_method_info_is_session_running_OUT_ARG_pointers,
    NULL
  },
  "handle-is-session-running",
  FALSE
};

static const _ExtendedGDBusMethodInfo * const _gsd_session_manager_method_info_pointers[] =
{
  &_gsd_session_manager_method_info_setenv,
  &_gsd_session_manager_method_info_get_locale,
  &_gsd_session_manager_method_info_initialization_error,
  &_gsd_session_manager_method_info_register_client,
  &_gsd_session_manager_method_info_unregister_client,
  &_gsd_session_manager_method_info_inhibit,
  &_gsd_session_manager_method_info_uninhibit,
  &_gsd_session_manager_method_info_is_inhibited,
  &_gsd_session_manager_method_info_get_clients,
  &_gsd_session_manager_method_info_get_inhibitors,
  &_gsd_session_manager_method_info_is_autostart_condition_handled,
  &_gsd_session_manager_method_info_shutdown,
  &_gsd_session_manager_method_info_reboot,
  &_gsd_session_manager_method_info_can_shutdown,
  &_gsd_session_manager_method_info_logout,
  &_gsd_session_manager_method_info_is_session_running,
  NULL
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_signal_info_client_added_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "o",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_signal_info_client_added_ARG_pointers[] =
{
  &_gsd_session_manager_signal_info_client_added_ARG_id,
  NULL
};

static const _ExtendedGDBusSignalInfo _gsd_session_manager_signal_info_client_added =
{
  {
    -1,
    (gchar *) "ClientAdded",
    (GDBusArgInfo **) &_gsd_session_manager_signal_info_client_added_ARG_pointers,
    NULL
  },
  "client-added"
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_signal_info_client_removed_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "o",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_signal_info_client_removed_ARG_pointers[] =
{
  &_gsd_session_manager_signal_info_client_removed_ARG_id,
  NULL
};

static const _ExtendedGDBusSignalInfo _gsd_session_manager_signal_info_client_removed =
{
  {
    -1,
    (gchar *) "ClientRemoved",
    (GDBusArgInfo **) &_gsd_session_manager_signal_info_client_removed_ARG_pointers,
    NULL
  },
  "client-removed"
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_signal_info_inhibitor_added_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "o",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_signal_info_inhibitor_added_ARG_pointers[] =
{
  &_gsd_session_manager_signal_info_inhibitor_added_ARG_id,
  NULL
};

static const _ExtendedGDBusSignalInfo _gsd_session_manager_signal_info_inhibitor_added =
{
  {
    -1,
    (gchar *) "InhibitorAdded",
    (GDBusArgInfo **) &_gsd_session_manager_signal_info_inhibitor_added_ARG_pointers,
    NULL
  },
  "inhibitor-added"
};

static const _ExtendedGDBusArgInfo _gsd_session_manager_signal_info_inhibitor_removed_ARG_id =
{
  {
    -1,
    (gchar *) "id",
    (gchar *) "o",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo * const _gsd_session_manager_signal_info_inhibitor_removed_ARG_pointers[] =
{
  &_gsd_session_manager_signal_info_inhibitor_removed_ARG_id,
  NULL
};

static const _ExtendedGDBusSignalInfo _gsd_session_manager_signal_info_inhibitor_removed =
{
  {
    -1,
    (gchar *) "InhibitorRemoved",
    (GDBusArgInfo **) &_gsd_session_manager_signal_info_inhibitor_removed_ARG_pointers,
    NULL
  },
  "inhibitor-removed"
};

static const _ExtendedGDBusSignalInfo _gsd_session_manager_signal_info_session_running =
{
  {
    -1,
    (gchar *) "SessionRunning",
    NULL,
    NULL
  },
  "session-running"
};

static const _ExtendedGDBusSignalInfo _gsd_session_manager_signal_info_session_over =
{
  {
    -1,
    (gchar *) "SessionOver",
    NULL,
    NULL
  },
  "session-over"
};

static const _ExtendedGDBusSignalInfo * const _gsd_session_manager_signal_info_pointers[] =
{
  &_gsd_session_manager_signal_info_client_added,
  &_gsd_session_manager_signal_info_client_removed,
  &_gsd_session_manager_signal_info_inhibitor_added,
  &_gsd_session_manager_signal_info_inhibitor_removed,
  &_gsd_session_manager_signal_info_session_running,
  &_gsd_session_manager_signal_info_session_over,
  NULL
};

static const _ExtendedGDBusPropertyInfo _gsd_session_manager_property_info_session_name =
{
  {
    -1,
    (gchar *) "SessionName",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "session-name",
  FALSE
};

static const _ExtendedGDBusPropertyInfo _gsd_session_manager_property_info_session_is_active =
{
  {
    -1,
    (gchar *) "SessionIsActive",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "session-is-active",
  FALSE
};

static const _ExtendedGDBusPropertyInfo _gsd_session_manager_property_info_inhibited_actions =
{
  {
    -1,
    (gchar *) "InhibitedActions",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "inhibited-actions",
  FALSE
};

static const _ExtendedGDBusPropertyInfo * const _gsd_session_manager_property_info_pointers[] =
{
  &_gsd_session_manager_property_info_session_name,
  &_gsd_session_manager_property_info_session_is_active,
  &_gsd_session_manager_property_info_inhibited_actions,
  NULL
};

static const _ExtendedGDBusInterfaceInfo _gsd_session_manager_interface_info =
{
  {
    -1,
    (gchar *) "org.gnome.SessionManager",
    (GDBusMethodInfo **) &_gsd_session_manager_method_info_pointers,
    (GDBusSignalInfo **) &_gsd_session_manager_signal_info_pointers,
    (GDBusPropertyInfo **) &_gsd_session_manager_property_info_pointers,
    NULL
  },
  "session-manager",
};


/**
 * gsd_session_manager_interface_info:
 *
 * Gets a machine-readable description of the <link linkend="gdbus-interface-org-gnome-SessionManager.top_of_page">org.gnome.SessionManager</link> D-Bus interface.
 *
 * Returns: (transfer none): A #GDBusInterfaceInfo. Do not free.
 */
GDBusInterfaceInfo *
gsd_session_manager_interface_info (void)
{
  return (GDBusInterfaceInfo *) &_gsd_session_manager_interface_info.parent_struct;
}

/**
 * gsd_session_manager_override_properties:
 * @klass: The class structure for a #GObject<!-- -->-derived class.
 * @property_id_begin: The property id to assign to the first overridden property.
 *
 * Overrides all #GObject properties in the #GsdSessionManager interface for a concrete class.
 * The properties are overridden in the order they are defined.
 *
 * Returns: The last property id.
 */
guint
gsd_session_manager_override_properties (GObjectClass *klass, guint property_id_begin)
{
  g_object_class_override_property (klass, property_id_begin++, "session-name");
  g_object_class_override_property (klass, property_id_begin++, "session-is-active");
  g_object_class_override_property (klass, property_id_begin++, "inhibited-actions");
  return property_id_begin - 1;
}



/**
 * GsdSessionManager:
 *
 * Abstract interface type for the D-Bus interface <link linkend="gdbus-interface-org-gnome-SessionManager.top_of_page">org.gnome.SessionManager</link>.
 */

/**
 * GsdSessionManagerIface:
 * @parent_iface: The parent interface.
 * @handle_can_shutdown: Handler for the #GsdSessionManager::handle-can-shutdown signal.
 * @handle_get_clients: Handler for the #GsdSessionManager::handle-get-clients signal.
 * @handle_get_inhibitors: Handler for the #GsdSessionManager::handle-get-inhibitors signal.
 * @handle_get_locale: Handler for the #GsdSessionManager::handle-get-locale signal.
 * @handle_inhibit: Handler for the #GsdSessionManager::handle-inhibit signal.
 * @handle_initialization_error: Handler for the #GsdSessionManager::handle-initialization-error signal.
 * @handle_is_autostart_condition_handled: Handler for the #GsdSessionManager::handle-is-autostart-condition-handled signal.
 * @handle_is_inhibited: Handler for the #GsdSessionManager::handle-is-inhibited signal.
 * @handle_is_session_running: Handler for the #GsdSessionManager::handle-is-session-running signal.
 * @handle_logout: Handler for the #GsdSessionManager::handle-logout signal.
 * @handle_reboot: Handler for the #GsdSessionManager::handle-reboot signal.
 * @handle_register_client: Handler for the #GsdSessionManager::handle-register-client signal.
 * @handle_setenv: Handler for the #GsdSessionManager::handle-setenv signal.
 * @handle_shutdown: Handler for the #GsdSessionManager::handle-shutdown signal.
 * @handle_uninhibit: Handler for the #GsdSessionManager::handle-uninhibit signal.
 * @handle_unregister_client: Handler for the #GsdSessionManager::handle-unregister-client signal.
 * @get_inhibited_actions: Getter for the #GsdSessionManager:inhibited-actions property.
 * @get_session_is_active: Getter for the #GsdSessionManager:session-is-active property.
 * @get_session_name: Getter for the #GsdSessionManager:session-name property.
 * @client_added: Handler for the #GsdSessionManager::client-added signal.
 * @client_removed: Handler for the #GsdSessionManager::client-removed signal.
 * @inhibitor_added: Handler for the #GsdSessionManager::inhibitor-added signal.
 * @inhibitor_removed: Handler for the #GsdSessionManager::inhibitor-removed signal.
 * @session_over: Handler for the #GsdSessionManager::session-over signal.
 * @session_running: Handler for the #GsdSessionManager::session-running signal.
 *
 * Virtual table for the D-Bus interface <link linkend="gdbus-interface-org-gnome-SessionManager.top_of_page">org.gnome.SessionManager</link>.
 */

typedef GsdSessionManagerIface GsdSessionManagerInterface;
G_DEFINE_INTERFACE (GsdSessionManager, gsd_session_manager, G_TYPE_OBJECT);

static void
gsd_session_manager_default_init (GsdSessionManagerIface *iface)
{
  /* GObject signals for incoming D-Bus method calls: */
  /**
   * GsdSessionManager::handle-setenv:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_variable: Argument passed by remote caller.
   * @arg_value: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.Setenv">Setenv()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_setenv() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-setenv",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_setenv),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING);

  /**
   * GsdSessionManager::handle-get-locale:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_category: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.GetLocale">GetLocale()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_get_locale() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-get-locale",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_get_locale),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_INT);

  /**
   * GsdSessionManager::handle-initialization-error:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_message: Argument passed by remote caller.
   * @arg_fatal: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.InitializationError">InitializationError()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_initialization_error() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-initialization-error",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_initialization_error),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_BOOLEAN);

  /**
   * GsdSessionManager::handle-register-client:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_app_id: Argument passed by remote caller.
   * @arg_client_startup_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.RegisterClient">RegisterClient()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_register_client() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-register-client",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_register_client),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    3,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_STRING);

  /**
   * GsdSessionManager::handle-unregister-client:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_client_id: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.UnregisterClient">UnregisterClient()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_unregister_client() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-unregister-client",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_unregister_client),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * GsdSessionManager::handle-inhibit:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_app_id: Argument passed by remote caller.
   * @arg_toplevel_xid: Argument passed by remote caller.
   * @arg_reason: Argument passed by remote caller.
   * @arg_flags: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.Inhibit">Inhibit()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_inhibit() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-inhibit",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_inhibit),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    5,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_UINT);

  /**
   * GsdSessionManager::handle-uninhibit:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_inhibit_cookie: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.Uninhibit">Uninhibit()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_uninhibit() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-uninhibit",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_uninhibit),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_UINT);

  /**
   * GsdSessionManager::handle-is-inhibited:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_flags: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.IsInhibited">IsInhibited()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_is_inhibited() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-is-inhibited",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_is_inhibited),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_UINT);

  /**
   * GsdSessionManager::handle-get-clients:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.GetClients">GetClients()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_get_clients() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-get-clients",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_get_clients),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GsdSessionManager::handle-get-inhibitors:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.GetInhibitors">GetInhibitors()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_get_inhibitors() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-get-inhibitors",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_get_inhibitors),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GsdSessionManager::handle-is-autostart-condition-handled:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_condition: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.IsAutostartConditionHandled">IsAutostartConditionHandled()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_is_autostart_condition_handled() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-is-autostart-condition-handled",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_is_autostart_condition_handled),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /**
   * GsdSessionManager::handle-shutdown:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.Shutdown">Shutdown()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_shutdown() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-shutdown",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_shutdown),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GsdSessionManager::handle-reboot:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.Reboot">Reboot()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_reboot() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-reboot",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_reboot),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GsdSessionManager::handle-can-shutdown:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.CanShutdown">CanShutdown()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_can_shutdown() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-can-shutdown",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_can_shutdown),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GsdSessionManager::handle-logout:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_mode: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.Logout">Logout()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_logout() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-logout",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_logout),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_UINT);

  /**
   * GsdSessionManager::handle-is-session-running:
   * @object: A #GsdSessionManager.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-gnome-SessionManager.IsSessionRunning">IsSessionRunning()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gsd_session_manager_complete_is_session_running() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-is-session-running",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, handle_is_session_running),
    g_signal_accumulator_true_handled,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /* GObject signals for received D-Bus signals: */
  /**
   * GsdSessionManager::client-added:
   * @object: A #GsdSessionManager.
   * @arg_id: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gnome-SessionManager.ClientAdded">"ClientAdded"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("client-added",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, client_added),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    1, G_TYPE_STRING);

  /**
   * GsdSessionManager::client-removed:
   * @object: A #GsdSessionManager.
   * @arg_id: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gnome-SessionManager.ClientRemoved">"ClientRemoved"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("client-removed",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, client_removed),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    1, G_TYPE_STRING);

  /**
   * GsdSessionManager::inhibitor-added:
   * @object: A #GsdSessionManager.
   * @arg_id: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gnome-SessionManager.InhibitorAdded">"InhibitorAdded"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("inhibitor-added",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, inhibitor_added),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    1, G_TYPE_STRING);

  /**
   * GsdSessionManager::inhibitor-removed:
   * @object: A #GsdSessionManager.
   * @arg_id: Argument.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gnome-SessionManager.InhibitorRemoved">"InhibitorRemoved"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("inhibitor-removed",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, inhibitor_removed),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    1, G_TYPE_STRING);

  /**
   * GsdSessionManager::session-running:
   * @object: A #GsdSessionManager.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gnome-SessionManager.SessionRunning">"SessionRunning"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("session-running",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, session_running),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    0);

  /**
   * GsdSessionManager::session-over:
   * @object: A #GsdSessionManager.
   *
   * On the client-side, this signal is emitted whenever the D-Bus signal <link linkend="gdbus-signal-org-gnome-SessionManager.SessionOver">"SessionOver"</link> is received.
   *
   * On the service-side, this signal can be used with e.g. g_signal_emit_by_name() to make the object emit the D-Bus signal.
   */
  g_signal_new ("session-over",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GsdSessionManagerIface, session_over),
    NULL,
    NULL,
    g_cclosure_marshal_generic,
    G_TYPE_NONE,
    0);

  /* GObject properties for D-Bus properties: */
  /**
   * GsdSessionManager:session-name:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-gnome-SessionManager.SessionName">"SessionName"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("session-name", "SessionName", "SessionName", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GsdSessionManager:session-is-active:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-gnome-SessionManager.SessionIsActive">"SessionIsActive"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("session-is-active", "SessionIsActive", "SessionIsActive", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GsdSessionManager:inhibited-actions:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-gnome-SessionManager.InhibitedActions">"InhibitedActions"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("inhibited-actions", "InhibitedActions", "InhibitedActions", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
}

/**
 * gsd_session_manager_get_session_name: (skip)
 * @object: A #GsdSessionManager.
 *
 * Gets the value of the <link linkend="gdbus-property-org-gnome-SessionManager.SessionName">"SessionName"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * <warning>The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use gsd_session_manager_dup_session_name() if on another thread.</warning>
 *
 * Returns: (transfer none): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
gsd_session_manager_get_session_name (GsdSessionManager *object)
{
  return GSD_SESSION_MANAGER_GET_IFACE (object)->get_session_name (object);
}

/**
 * gsd_session_manager_dup_session_name: (skip)
 * @object: A #GsdSessionManager.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-gnome-SessionManager.SessionName">"SessionName"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
gsd_session_manager_dup_session_name (GsdSessionManager *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "session-name", &value, NULL);
  return value;
}

/**
 * gsd_session_manager_set_session_name: (skip)
 * @object: A #GsdSessionManager.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-gnome-SessionManager.SessionName">"SessionName"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gsd_session_manager_set_session_name (GsdSessionManager *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "session-name", value, NULL);
}

/**
 * gsd_session_manager_get_session_is_active: (skip)
 * @object: A #GsdSessionManager.
 *
 * Gets the value of the <link linkend="gdbus-property-org-gnome-SessionManager.SessionIsActive">"SessionIsActive"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
gsd_session_manager_get_session_is_active (GsdSessionManager *object)
{
  return GSD_SESSION_MANAGER_GET_IFACE (object)->get_session_is_active (object);
}

/**
 * gsd_session_manager_set_session_is_active: (skip)
 * @object: A #GsdSessionManager.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-gnome-SessionManager.SessionIsActive">"SessionIsActive"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gsd_session_manager_set_session_is_active (GsdSessionManager *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "session-is-active", value, NULL);
}

/**
 * gsd_session_manager_get_inhibited_actions: (skip)
 * @object: A #GsdSessionManager.
 *
 * Gets the value of the <link linkend="gdbus-property-org-gnome-SessionManager.InhibitedActions">"InhibitedActions"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
gsd_session_manager_get_inhibited_actions (GsdSessionManager *object)
{
  return GSD_SESSION_MANAGER_GET_IFACE (object)->get_inhibited_actions (object);
}

/**
 * gsd_session_manager_set_inhibited_actions: (skip)
 * @object: A #GsdSessionManager.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-gnome-SessionManager.InhibitedActions">"InhibitedActions"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gsd_session_manager_set_inhibited_actions (GsdSessionManager *object, guint value)
{
  g_object_set (G_OBJECT (object), "inhibited-actions", value, NULL);
}

/**
 * gsd_session_manager_emit_client_added:
 * @object: A #GsdSessionManager.
 * @arg_id: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gnome-SessionManager.ClientAdded">"ClientAdded"</link> D-Bus signal.
 */
void
gsd_session_manager_emit_client_added (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  g_signal_emit_by_name (object, "client-added", arg_id);
}

/**
 * gsd_session_manager_emit_client_removed:
 * @object: A #GsdSessionManager.
 * @arg_id: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gnome-SessionManager.ClientRemoved">"ClientRemoved"</link> D-Bus signal.
 */
void
gsd_session_manager_emit_client_removed (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  g_signal_emit_by_name (object, "client-removed", arg_id);
}

/**
 * gsd_session_manager_emit_inhibitor_added:
 * @object: A #GsdSessionManager.
 * @arg_id: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gnome-SessionManager.InhibitorAdded">"InhibitorAdded"</link> D-Bus signal.
 */
void
gsd_session_manager_emit_inhibitor_added (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  g_signal_emit_by_name (object, "inhibitor-added", arg_id);
}

/**
 * gsd_session_manager_emit_inhibitor_removed:
 * @object: A #GsdSessionManager.
 * @arg_id: Argument to pass with the signal.
 *
 * Emits the <link linkend="gdbus-signal-org-gnome-SessionManager.InhibitorRemoved">"InhibitorRemoved"</link> D-Bus signal.
 */
void
gsd_session_manager_emit_inhibitor_removed (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  g_signal_emit_by_name (object, "inhibitor-removed", arg_id);
}

/**
 * gsd_session_manager_emit_session_running:
 * @object: A #GsdSessionManager.
 *
 * Emits the <link linkend="gdbus-signal-org-gnome-SessionManager.SessionRunning">"SessionRunning"</link> D-Bus signal.
 */
void
gsd_session_manager_emit_session_running (
    GsdSessionManager *object)
{
  g_signal_emit_by_name (object, "session-running");
}

/**
 * gsd_session_manager_emit_session_over:
 * @object: A #GsdSessionManager.
 *
 * Emits the <link linkend="gdbus-signal-org-gnome-SessionManager.SessionOver">"SessionOver"</link> D-Bus signal.
 */
void
gsd_session_manager_emit_session_over (
    GsdSessionManager *object)
{
  g_signal_emit_by_name (object, "session-over");
}

/**
 * gsd_session_manager_call_setenv:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_variable: Argument to pass with the method invocation.
 * @arg_value: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Setenv">Setenv()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_setenv_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_setenv_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_setenv (
    GsdSessionManager *proxy,
    const gchar *arg_variable,
    const gchar *arg_value,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Setenv",
    g_variant_new ("(ss)",
                   arg_variable,
                   arg_value),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_setenv_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_setenv().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_setenv().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_setenv_finish (
    GsdSessionManager *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_setenv_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_variable: Argument to pass with the method invocation.
 * @arg_value: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Setenv">Setenv()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_setenv() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_setenv_sync (
    GsdSessionManager *proxy,
    const gchar *arg_variable,
    const gchar *arg_value,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Setenv",
    g_variant_new ("(ss)",
                   arg_variable,
                   arg_value),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_get_locale:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_category: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.GetLocale">GetLocale()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_get_locale_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_get_locale_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_get_locale (
    GsdSessionManager *proxy,
    gint arg_category,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "GetLocale",
    g_variant_new ("(i)",
                   arg_category),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_get_locale_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_value: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_get_locale().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_get_locale().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_get_locale_finish (
    GsdSessionManager *proxy,
    gchar **out_value,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_value);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_get_locale_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_category: Argument to pass with the method invocation.
 * @out_value: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.GetLocale">GetLocale()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_get_locale() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_get_locale_sync (
    GsdSessionManager *proxy,
    gint arg_category,
    gchar **out_value,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "GetLocale",
    g_variant_new ("(i)",
                   arg_category),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(s)",
                 out_value);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_initialization_error:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_message: Argument to pass with the method invocation.
 * @arg_fatal: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.InitializationError">InitializationError()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_initialization_error_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_initialization_error_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_initialization_error (
    GsdSessionManager *proxy,
    const gchar *arg_message,
    gboolean arg_fatal,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "InitializationError",
    g_variant_new ("(sb)",
                   arg_message,
                   arg_fatal),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_initialization_error_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_initialization_error().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_initialization_error().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_initialization_error_finish (
    GsdSessionManager *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_initialization_error_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_message: Argument to pass with the method invocation.
 * @arg_fatal: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.InitializationError">InitializationError()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_initialization_error() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_initialization_error_sync (
    GsdSessionManager *proxy,
    const gchar *arg_message,
    gboolean arg_fatal,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "InitializationError",
    g_variant_new ("(sb)",
                   arg_message,
                   arg_fatal),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_register_client:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_app_id: Argument to pass with the method invocation.
 * @arg_client_startup_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.RegisterClient">RegisterClient()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_register_client_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_register_client_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_register_client (
    GsdSessionManager *proxy,
    const gchar *arg_app_id,
    const gchar *arg_client_startup_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "RegisterClient",
    g_variant_new ("(ss)",
                   arg_app_id,
                   arg_client_startup_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_register_client_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_client_id: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_register_client().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_register_client().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_register_client_finish (
    GsdSessionManager *proxy,
    gchar **out_client_id,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(o)",
                 out_client_id);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_register_client_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_app_id: Argument to pass with the method invocation.
 * @arg_client_startup_id: Argument to pass with the method invocation.
 * @out_client_id: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.RegisterClient">RegisterClient()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_register_client() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_register_client_sync (
    GsdSessionManager *proxy,
    const gchar *arg_app_id,
    const gchar *arg_client_startup_id,
    gchar **out_client_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "RegisterClient",
    g_variant_new ("(ss)",
                   arg_app_id,
                   arg_client_startup_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(o)",
                 out_client_id);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_unregister_client:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_client_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.UnregisterClient">UnregisterClient()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_unregister_client_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_unregister_client_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_unregister_client (
    GsdSessionManager *proxy,
    const gchar *arg_client_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "UnregisterClient",
    g_variant_new ("(o)",
                   arg_client_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_unregister_client_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_unregister_client().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_unregister_client().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_unregister_client_finish (
    GsdSessionManager *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_unregister_client_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_client_id: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.UnregisterClient">UnregisterClient()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_unregister_client() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_unregister_client_sync (
    GsdSessionManager *proxy,
    const gchar *arg_client_id,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "UnregisterClient",
    g_variant_new ("(o)",
                   arg_client_id),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_inhibit:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_app_id: Argument to pass with the method invocation.
 * @arg_toplevel_xid: Argument to pass with the method invocation.
 * @arg_reason: Argument to pass with the method invocation.
 * @arg_flags: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Inhibit">Inhibit()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_inhibit_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_inhibit_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_inhibit (
    GsdSessionManager *proxy,
    const gchar *arg_app_id,
    guint arg_toplevel_xid,
    const gchar *arg_reason,
    guint arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Inhibit",
    g_variant_new ("(susu)",
                   arg_app_id,
                   arg_toplevel_xid,
                   arg_reason,
                   arg_flags),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_inhibit_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_inhibit_cookie: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_inhibit().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_inhibit().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_inhibit_finish (
    GsdSessionManager *proxy,
    guint *out_inhibit_cookie,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(u)",
                 out_inhibit_cookie);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_inhibit_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_app_id: Argument to pass with the method invocation.
 * @arg_toplevel_xid: Argument to pass with the method invocation.
 * @arg_reason: Argument to pass with the method invocation.
 * @arg_flags: Argument to pass with the method invocation.
 * @out_inhibit_cookie: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Inhibit">Inhibit()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_inhibit() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_inhibit_sync (
    GsdSessionManager *proxy,
    const gchar *arg_app_id,
    guint arg_toplevel_xid,
    const gchar *arg_reason,
    guint arg_flags,
    guint *out_inhibit_cookie,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Inhibit",
    g_variant_new ("(susu)",
                   arg_app_id,
                   arg_toplevel_xid,
                   arg_reason,
                   arg_flags),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(u)",
                 out_inhibit_cookie);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_uninhibit:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_inhibit_cookie: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Uninhibit">Uninhibit()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_uninhibit_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_uninhibit_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_uninhibit (
    GsdSessionManager *proxy,
    guint arg_inhibit_cookie,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Uninhibit",
    g_variant_new ("(u)",
                   arg_inhibit_cookie),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_uninhibit_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_uninhibit().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_uninhibit().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_uninhibit_finish (
    GsdSessionManager *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_uninhibit_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_inhibit_cookie: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Uninhibit">Uninhibit()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_uninhibit() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_uninhibit_sync (
    GsdSessionManager *proxy,
    guint arg_inhibit_cookie,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Uninhibit",
    g_variant_new ("(u)",
                   arg_inhibit_cookie),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_is_inhibited:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_flags: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.IsInhibited">IsInhibited()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_is_inhibited_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_is_inhibited_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_is_inhibited (
    GsdSessionManager *proxy,
    guint arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "IsInhibited",
    g_variant_new ("(u)",
                   arg_flags),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_is_inhibited_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_is_inhibited: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_is_inhibited().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_is_inhibited().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_is_inhibited_finish (
    GsdSessionManager *proxy,
    gboolean *out_is_inhibited,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_is_inhibited);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_is_inhibited_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_flags: Argument to pass with the method invocation.
 * @out_is_inhibited: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.IsInhibited">IsInhibited()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_is_inhibited() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_is_inhibited_sync (
    GsdSessionManager *proxy,
    guint arg_flags,
    gboolean *out_is_inhibited,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "IsInhibited",
    g_variant_new ("(u)",
                   arg_flags),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_is_inhibited);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_get_clients:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.GetClients">GetClients()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_get_clients_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_get_clients_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_get_clients (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "GetClients",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_get_clients_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_clients: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_get_clients().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_get_clients().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_get_clients_finish (
    GsdSessionManager *proxy,
    gchar ***out_clients,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^ao)",
                 out_clients);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_get_clients_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_clients: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.GetClients">GetClients()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_get_clients() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_get_clients_sync (
    GsdSessionManager *proxy,
    gchar ***out_clients,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "GetClients",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^ao)",
                 out_clients);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_get_inhibitors:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.GetInhibitors">GetInhibitors()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_get_inhibitors_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_get_inhibitors_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_get_inhibitors (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "GetInhibitors",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_get_inhibitors_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_inhibitors: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_get_inhibitors().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_get_inhibitors().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_get_inhibitors_finish (
    GsdSessionManager *proxy,
    gchar ***out_inhibitors,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^ao)",
                 out_inhibitors);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_get_inhibitors_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_inhibitors: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.GetInhibitors">GetInhibitors()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_get_inhibitors() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_get_inhibitors_sync (
    GsdSessionManager *proxy,
    gchar ***out_inhibitors,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "GetInhibitors",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(^ao)",
                 out_inhibitors);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_is_autostart_condition_handled:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_condition: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.IsAutostartConditionHandled">IsAutostartConditionHandled()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_is_autostart_condition_handled_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_is_autostart_condition_handled_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_is_autostart_condition_handled (
    GsdSessionManager *proxy,
    const gchar *arg_condition,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "IsAutostartConditionHandled",
    g_variant_new ("(s)",
                   arg_condition),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_is_autostart_condition_handled_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_handled: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_is_autostart_condition_handled().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_is_autostart_condition_handled().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_is_autostart_condition_handled_finish (
    GsdSessionManager *proxy,
    gboolean *out_handled,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_handled);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_is_autostart_condition_handled_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_condition: Argument to pass with the method invocation.
 * @out_handled: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.IsAutostartConditionHandled">IsAutostartConditionHandled()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_is_autostart_condition_handled() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_is_autostart_condition_handled_sync (
    GsdSessionManager *proxy,
    const gchar *arg_condition,
    gboolean *out_handled,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "IsAutostartConditionHandled",
    g_variant_new ("(s)",
                   arg_condition),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_handled);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_shutdown:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Shutdown">Shutdown()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_shutdown_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_shutdown_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_shutdown (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Shutdown",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_shutdown_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_shutdown().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_shutdown().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_shutdown_finish (
    GsdSessionManager *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_shutdown_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Shutdown">Shutdown()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_shutdown() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_shutdown_sync (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Shutdown",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_reboot:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Reboot">Reboot()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_reboot_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_reboot_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_reboot (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Reboot",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_reboot_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_reboot().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_reboot().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_reboot_finish (
    GsdSessionManager *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_reboot_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Reboot">Reboot()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_reboot() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_reboot_sync (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Reboot",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_can_shutdown:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.CanShutdown">CanShutdown()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_can_shutdown_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_can_shutdown_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_can_shutdown (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "CanShutdown",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_can_shutdown_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_is_available: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_can_shutdown().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_can_shutdown().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_can_shutdown_finish (
    GsdSessionManager *proxy,
    gboolean *out_is_available,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_is_available);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_can_shutdown_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_is_available: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.CanShutdown">CanShutdown()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_can_shutdown() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_can_shutdown_sync (
    GsdSessionManager *proxy,
    gboolean *out_is_available,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "CanShutdown",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_is_available);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_logout:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_mode: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Logout">Logout()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_logout_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_logout_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_logout (
    GsdSessionManager *proxy,
    guint arg_mode,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Logout",
    g_variant_new ("(u)",
                   arg_mode),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_logout_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_logout().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_logout().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_logout_finish (
    GsdSessionManager *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_logout_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @arg_mode: Argument to pass with the method invocation.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.Logout">Logout()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_logout() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_logout_sync (
    GsdSessionManager *proxy,
    guint arg_mode,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Logout",
    g_variant_new ("(u)",
                   arg_mode),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_is_session_running:
 * @proxy: A #GsdSessionManagerProxy.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.IsSessionRunning">IsSessionRunning()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_call_is_session_running_finish() to get the result of the operation.
 *
 * See gsd_session_manager_call_is_session_running_sync() for the synchronous, blocking version of this method.
 */
void
gsd_session_manager_call_is_session_running (
    GsdSessionManager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "IsSessionRunning",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gsd_session_manager_call_is_session_running_finish:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_running: (out): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_call_is_session_running().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gsd_session_manager_call_is_session_running().
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_is_session_running_finish (
    GsdSessionManager *proxy,
    gboolean *out_running,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_running);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_call_is_session_running_sync:
 * @proxy: A #GsdSessionManagerProxy.
 * @out_running: (out): Return location for return parameter or %NULL to ignore.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-gnome-SessionManager.IsSessionRunning">IsSessionRunning()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_call_is_session_running() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
 */
gboolean
gsd_session_manager_call_is_session_running_sync (
    GsdSessionManager *proxy,
    gboolean *out_running,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "IsSessionRunning",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(b)",
                 out_running);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gsd_session_manager_complete_setenv:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.Setenv">Setenv()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_setenv (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gsd_session_manager_complete_get_locale:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @value: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.GetLocale">GetLocale()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_get_locale (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    const gchar *value)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(s)",
                   value));
}

/**
 * gsd_session_manager_complete_initialization_error:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.InitializationError">InitializationError()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_initialization_error (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gsd_session_manager_complete_register_client:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @client_id: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.RegisterClient">RegisterClient()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_register_client (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    const gchar *client_id)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(o)",
                   client_id));
}

/**
 * gsd_session_manager_complete_unregister_client:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.UnregisterClient">UnregisterClient()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_unregister_client (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gsd_session_manager_complete_inhibit:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @inhibit_cookie: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.Inhibit">Inhibit()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_inhibit (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    guint inhibit_cookie)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(u)",
                   inhibit_cookie));
}

/**
 * gsd_session_manager_complete_uninhibit:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.Uninhibit">Uninhibit()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_uninhibit (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gsd_session_manager_complete_is_inhibited:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @is_inhibited: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.IsInhibited">IsInhibited()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_is_inhibited (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    gboolean is_inhibited)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(b)",
                   is_inhibited));
}

/**
 * gsd_session_manager_complete_get_clients:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @clients: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.GetClients">GetClients()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_get_clients (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *clients)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^ao)",
                   clients));
}

/**
 * gsd_session_manager_complete_get_inhibitors:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @inhibitors: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.GetInhibitors">GetInhibitors()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_get_inhibitors (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *inhibitors)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(^ao)",
                   inhibitors));
}

/**
 * gsd_session_manager_complete_is_autostart_condition_handled:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @handled: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.IsAutostartConditionHandled">IsAutostartConditionHandled()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_is_autostart_condition_handled (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    gboolean handled)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(b)",
                   handled));
}

/**
 * gsd_session_manager_complete_shutdown:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.Shutdown">Shutdown()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_shutdown (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gsd_session_manager_complete_reboot:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.Reboot">Reboot()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_reboot (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gsd_session_manager_complete_can_shutdown:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @is_available: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.CanShutdown">CanShutdown()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_can_shutdown (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    gboolean is_available)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(b)",
                   is_available));
}

/**
 * gsd_session_manager_complete_logout:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.Logout">Logout()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_logout (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gsd_session_manager_complete_is_session_running:
 * @object: A #GsdSessionManager.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @running: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-gnome-SessionManager.IsSessionRunning">IsSessionRunning()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gsd_session_manager_complete_is_session_running (
    GsdSessionManager *object,
    GDBusMethodInvocation *invocation,
    gboolean running)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(b)",
                   running));
}

/* ------------------------------------------------------------------------ */

/**
 * GsdSessionManagerProxy:
 *
 * The #GsdSessionManagerProxy structure contains only private data and should only be accessed using the provided API.
 */

/**
 * GsdSessionManagerProxyClass:
 * @parent_class: The parent class.
 *
 * Class structure for #GsdSessionManagerProxy.
 */

struct _GsdSessionManagerProxyPrivate
{
  GData *qdata;
};

static void gsd_session_manager_proxy_iface_init (GsdSessionManagerIface *iface);

#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (GsdSessionManagerProxy, gsd_session_manager_proxy, G_TYPE_DBUS_PROXY,
                         G_ADD_PRIVATE (GsdSessionManagerProxy)
                         G_IMPLEMENT_INTERFACE (GSD_TYPE_SESSION_MANAGER, gsd_session_manager_proxy_iface_init));

#else
G_DEFINE_TYPE_WITH_CODE (GsdSessionManagerProxy, gsd_session_manager_proxy, G_TYPE_DBUS_PROXY,
                         G_IMPLEMENT_INTERFACE (GSD_TYPE_SESSION_MANAGER, gsd_session_manager_proxy_iface_init));

#endif
static void
gsd_session_manager_proxy_finalize (GObject *object)
{
  GsdSessionManagerProxy *proxy = GSD_SESSION_MANAGER_PROXY (object);
  g_datalist_clear (&proxy->priv->qdata);
  G_OBJECT_CLASS (gsd_session_manager_proxy_parent_class)->finalize (object);
}

static void
gsd_session_manager_proxy_get_property (GObject      *object,
  guint         prop_id,
  GValue       *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  const _ExtendedGDBusPropertyInfo *info;
  GVariant *variant;
  g_assert (prop_id != 0 && prop_id - 1 < 3);
  info = _gsd_session_manager_property_info_pointers[prop_id - 1];
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (object), info->parent_struct.name);
  if (info->use_gvariant)
    {
      g_value_set_variant (value, variant);
    }
  else
    {
      if (variant != NULL)
        g_dbus_gvariant_to_gvalue (variant, value);
    }
  if (variant != NULL)
    g_variant_unref (variant);
}

static void
gsd_session_manager_proxy_set_property_cb (GDBusProxy *proxy,
  GAsyncResult *res,
  gpointer      user_data)
{
  const _ExtendedGDBusPropertyInfo *info = user_data;
  GError *error;
  GVariant *_ret;
  error = NULL;
  _ret = g_dbus_proxy_call_finish (proxy, res, &error);
  if (!_ret)
    {
      g_warning ("Error setting property '%s' on interface org.gnome.SessionManager: %s (%s, %d)",
                 info->parent_struct.name, 
                 error->message, g_quark_to_string (error->domain), error->code);
      g_error_free (error);
    }
  else
    {
      g_variant_unref (_ret);
    }
}

static void
gsd_session_manager_proxy_set_property (GObject      *object,
  guint         prop_id,
  const GValue *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  const _ExtendedGDBusPropertyInfo *info;
  GVariant *variant;
  g_assert (prop_id != 0 && prop_id - 1 < 3);
  info = _gsd_session_manager_property_info_pointers[prop_id - 1];
  variant = g_dbus_gvalue_to_gvariant (value, G_VARIANT_TYPE (info->parent_struct.signature));
  g_dbus_proxy_call (G_DBUS_PROXY (object),
    "org.freedesktop.DBus.Properties.Set",
    g_variant_new ("(ssv)", "org.gnome.SessionManager", info->parent_struct.name, variant),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    NULL, (GAsyncReadyCallback) gsd_session_manager_proxy_set_property_cb, (GDBusPropertyInfo *) &info->parent_struct);
  g_variant_unref (variant);
}

static void
gsd_session_manager_proxy_g_signal (GDBusProxy *proxy,
  const gchar *sender_name G_GNUC_UNUSED,
  const gchar *signal_name,
  GVariant *parameters)
{
  _ExtendedGDBusSignalInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  guint num_params;
  guint n;
  guint signal_id;
  info = (_ExtendedGDBusSignalInfo *) g_dbus_interface_info_lookup_signal ((GDBusInterfaceInfo *) &_gsd_session_manager_interface_info.parent_struct, signal_name);
  if (info == NULL)
    return;
  num_params = g_variant_n_children (parameters);
  paramv = g_new0 (GValue, num_params + 1);
  g_value_init (&paramv[0], GSD_TYPE_SESSION_MANAGER);
  g_value_set_object (&paramv[0], proxy);
  g_variant_iter_init (&iter, parameters);
  n = 1;
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.args[n - 1];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, GSD_TYPE_SESSION_MANAGER);
  g_signal_emitv (paramv, signal_id, 0, NULL);
  for (n = 0; n < num_params + 1; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static void
gsd_session_manager_proxy_g_properties_changed (GDBusProxy *_proxy,
  GVariant *changed_properties,
  const gchar *const *invalidated_properties)
{
  GsdSessionManagerProxy *proxy = GSD_SESSION_MANAGER_PROXY (_proxy);
  guint n;
  const gchar *key;
  GVariantIter *iter;
  _ExtendedGDBusPropertyInfo *info;
  g_variant_get (changed_properties, "a{sv}", &iter);
  while (g_variant_iter_next (iter, "{&sv}", &key, NULL))
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gsd_session_manager_interface_info.parent_struct, key);
      g_datalist_remove_data (&proxy->priv->qdata, key);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
  g_variant_iter_free (iter);
  for (n = 0; invalidated_properties[n] != NULL; n++)
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gsd_session_manager_interface_info.parent_struct, invalidated_properties[n]);
      g_datalist_remove_data (&proxy->priv->qdata, invalidated_properties[n]);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
}

static const gchar *
gsd_session_manager_proxy_get_session_name (GsdSessionManager *object)
{
  GsdSessionManagerProxy *proxy = GSD_SESSION_MANAGER_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "SessionName");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
gsd_session_manager_proxy_get_session_is_active (GsdSessionManager *object)
{
  GsdSessionManagerProxy *proxy = GSD_SESSION_MANAGER_PROXY (object);
  GVariant *variant;
  gboolean value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "SessionIsActive");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
gsd_session_manager_proxy_get_inhibited_actions (GsdSessionManager *object)
{
  GsdSessionManagerProxy *proxy = GSD_SESSION_MANAGER_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "InhibitedActions");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static void
gsd_session_manager_proxy_init (GsdSessionManagerProxy *proxy)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  proxy->priv = gsd_session_manager_proxy_get_instance_private (proxy);
#else
  proxy->priv = G_TYPE_INSTANCE_GET_PRIVATE (proxy, GSD_TYPE_SESSION_MANAGER_PROXY, GsdSessionManagerProxyPrivate);
#endif

  g_dbus_proxy_set_interface_info (G_DBUS_PROXY (proxy), gsd_session_manager_interface_info ());
}

static void
gsd_session_manager_proxy_class_init (GsdSessionManagerProxyClass *klass)
{
  GObjectClass *gobject_class;
  GDBusProxyClass *proxy_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize     = gsd_session_manager_proxy_finalize;
  gobject_class->get_property = gsd_session_manager_proxy_get_property;
  gobject_class->set_property = gsd_session_manager_proxy_set_property;

  proxy_class = G_DBUS_PROXY_CLASS (klass);
  proxy_class->g_signal = gsd_session_manager_proxy_g_signal;
  proxy_class->g_properties_changed = gsd_session_manager_proxy_g_properties_changed;

  gsd_session_manager_override_properties (gobject_class, 1);

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (GsdSessionManagerProxyPrivate));
#endif
}

static void
gsd_session_manager_proxy_iface_init (GsdSessionManagerIface *iface)
{
  iface->get_session_name = gsd_session_manager_proxy_get_session_name;
  iface->get_session_is_active = gsd_session_manager_proxy_get_session_is_active;
  iface->get_inhibited_actions = gsd_session_manager_proxy_get_inhibited_actions;
}

/**
 * gsd_session_manager_proxy_new:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (allow-none): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-gnome-SessionManager.top_of_page">org.gnome.SessionManager</link>. See g_dbus_proxy_new() for more details.
 *
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_proxy_new_finish() to get the result of the operation.
 *
 * See gsd_session_manager_proxy_new_sync() for the synchronous, blocking version of this constructor.
 */
void
gsd_session_manager_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (GSD_TYPE_SESSION_MANAGER_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.gnome.SessionManager", NULL);
}

/**
 * gsd_session_manager_proxy_new_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_proxy_new().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with gsd_session_manager_proxy_new().
 *
 * Returns: (transfer full) (type GsdSessionManagerProxy): The constructed proxy object or %NULL if @error is set.
 */
GsdSessionManager *
gsd_session_manager_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return GSD_SESSION_MANAGER (ret);
  else
    return NULL;
}

/**
 * gsd_session_manager_proxy_new_sync:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (allow-none): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Synchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-gnome-SessionManager.top_of_page">org.gnome.SessionManager</link>. See g_dbus_proxy_new_sync() for more details.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_proxy_new() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type GsdSessionManagerProxy): The constructed proxy object or %NULL if @error is set.
 */
GsdSessionManager *
gsd_session_manager_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (GSD_TYPE_SESSION_MANAGER_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.gnome.SessionManager", NULL);
  if (ret != NULL)
    return GSD_SESSION_MANAGER (ret);
  else
    return NULL;
}


/**
 * gsd_session_manager_proxy_new_for_bus:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Like gsd_session_manager_proxy_new() but takes a #GBusType instead of a #GDBusConnection.
 *
 * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
 * You can then call gsd_session_manager_proxy_new_for_bus_finish() to get the result of the operation.
 *
 * See gsd_session_manager_proxy_new_for_bus_sync() for the synchronous, blocking version of this constructor.
 */
void
gsd_session_manager_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (GSD_TYPE_SESSION_MANAGER_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.gnome.SessionManager", NULL);
}

/**
 * gsd_session_manager_proxy_new_for_bus_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gsd_session_manager_proxy_new_for_bus().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with gsd_session_manager_proxy_new_for_bus().
 *
 * Returns: (transfer full) (type GsdSessionManagerProxy): The constructed proxy object or %NULL if @error is set.
 */
GsdSessionManager *
gsd_session_manager_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return GSD_SESSION_MANAGER (ret);
  else
    return NULL;
}

/**
 * gsd_session_manager_proxy_new_for_bus_sync:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (allow-none): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Like gsd_session_manager_proxy_new_sync() but takes a #GBusType instead of a #GDBusConnection.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See gsd_session_manager_proxy_new_for_bus() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type GsdSessionManagerProxy): The constructed proxy object or %NULL if @error is set.
 */
GsdSessionManager *
gsd_session_manager_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (GSD_TYPE_SESSION_MANAGER_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.gnome.SessionManager", NULL);
  if (ret != NULL)
    return GSD_SESSION_MANAGER (ret);
  else
    return NULL;
}


/* ------------------------------------------------------------------------ */

/**
 * GsdSessionManagerSkeleton:
 *
 * The #GsdSessionManagerSkeleton structure contains only private data and should only be accessed using the provided API.
 */

/**
 * GsdSessionManagerSkeletonClass:
 * @parent_class: The parent class.
 *
 * Class structure for #GsdSessionManagerSkeleton.
 */

struct _GsdSessionManagerSkeletonPrivate
{
  GValue *properties;
  GList *changed_properties;
  GSource *changed_properties_idle_source;
  GMainContext *context;
  GMutex lock;
};

static void
_gsd_session_manager_skeleton_handle_method_call (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name,
  const gchar *method_name,
  GVariant *parameters,
  GDBusMethodInvocation *invocation,
  gpointer user_data)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (user_data);
  _ExtendedGDBusMethodInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  guint num_params;
  guint num_extra;
  guint n;
  guint signal_id;
  GValue return_value = G_VALUE_INIT;
  info = (_ExtendedGDBusMethodInfo *) g_dbus_method_invocation_get_method_info (invocation);
  g_assert (info != NULL);
  num_params = g_variant_n_children (parameters);
  num_extra = info->pass_fdlist ? 3 : 2;  paramv = g_new0 (GValue, num_params + num_extra);
  n = 0;
  g_value_init (&paramv[n], GSD_TYPE_SESSION_MANAGER);
  g_value_set_object (&paramv[n++], skeleton);
  g_value_init (&paramv[n], G_TYPE_DBUS_METHOD_INVOCATION);
  g_value_set_object (&paramv[n++], invocation);
  if (info->pass_fdlist)
    {
#ifdef G_OS_UNIX
      g_value_init (&paramv[n], G_TYPE_UNIX_FD_LIST);
      g_value_set_object (&paramv[n++], g_dbus_message_get_unix_fd_list (g_dbus_method_invocation_get_message (invocation)));
#else
      g_assert_not_reached ();
#endif
    }
  g_variant_iter_init (&iter, parameters);
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.in_args[n - num_extra];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, GSD_TYPE_SESSION_MANAGER);
  g_value_init (&return_value, G_TYPE_BOOLEAN);
  g_signal_emitv (paramv, signal_id, 0, &return_value);
  if (!g_value_get_boolean (&return_value))
    g_dbus_method_invocation_return_error (invocation, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD, "Method %s is not implemented on interface %s", method_name, interface_name);
  g_value_unset (&return_value);
  for (n = 0; n < num_params + num_extra; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static GVariant *
_gsd_session_manager_skeleton_handle_get_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GError **error,
  gpointer user_data)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  GVariant *ret;
  ret = NULL;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gsd_session_manager_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      g_value_init (&value, pspec->value_type);
      g_object_get_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      ret = g_dbus_gvalue_to_gvariant (&value, G_VARIANT_TYPE (info->parent_struct.signature));
      g_value_unset (&value);
    }
  return ret;
}

static gboolean
_gsd_session_manager_skeleton_handle_set_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GVariant *variant,
  GError **error,
  gpointer user_data)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  gboolean ret;
  ret = FALSE;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gsd_session_manager_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      if (info->use_gvariant)
        g_value_set_variant (&value, variant);
      else
        g_dbus_gvariant_to_gvalue (variant, &value);
      g_object_set_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      g_value_unset (&value);
      ret = TRUE;
    }
  return ret;
}

static const GDBusInterfaceVTable _gsd_session_manager_skeleton_vtable =
{
  _gsd_session_manager_skeleton_handle_method_call,
  _gsd_session_manager_skeleton_handle_get_property,
  _gsd_session_manager_skeleton_handle_set_property,
  {NULL}
};

static GDBusInterfaceInfo *
gsd_session_manager_skeleton_dbus_interface_get_info (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return gsd_session_manager_interface_info ();
}

static GDBusInterfaceVTable *
gsd_session_manager_skeleton_dbus_interface_get_vtable (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return (GDBusInterfaceVTable *) &_gsd_session_manager_skeleton_vtable;
}

static GVariant *
gsd_session_manager_skeleton_dbus_interface_get_properties (GDBusInterfaceSkeleton *_skeleton)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (_skeleton);

  GVariantBuilder builder;
  guint n;
  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
  if (_gsd_session_manager_interface_info.parent_struct.properties == NULL)
    goto out;
  for (n = 0; _gsd_session_manager_interface_info.parent_struct.properties[n] != NULL; n++)
    {
      GDBusPropertyInfo *info = _gsd_session_manager_interface_info.parent_struct.properties[n];
      if (info->flags & G_DBUS_PROPERTY_INFO_FLAGS_READABLE)
        {
          GVariant *value;
          value = _gsd_session_manager_skeleton_handle_get_property (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)), NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gnome.SessionManager", info->name, NULL, skeleton);
          if (value != NULL)
            {
              g_variant_take_ref (value);
              g_variant_builder_add (&builder, "{sv}", info->name, value);
              g_variant_unref (value);
            }
        }
    }
out:
  return g_variant_builder_end (&builder);
}

static gboolean _gsd_session_manager_emit_changed (gpointer user_data);

static void
gsd_session_manager_skeleton_dbus_interface_flush (GDBusInterfaceSkeleton *_skeleton)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (_skeleton);
  gboolean emit_changed = FALSE;

  g_mutex_lock (&skeleton->priv->lock);
  if (skeleton->priv->changed_properties_idle_source != NULL)
    {
      g_source_destroy (skeleton->priv->changed_properties_idle_source);
      skeleton->priv->changed_properties_idle_source = NULL;
      emit_changed = TRUE;
    }
  g_mutex_unlock (&skeleton->priv->lock);

  if (emit_changed)
    _gsd_session_manager_emit_changed (skeleton);
}

static void
_gsd_session_manager_on_signal_client_added (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(o)",
                   arg_id));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gnome.SessionManager", "ClientAdded",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gsd_session_manager_on_signal_client_removed (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(o)",
                   arg_id));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gnome.SessionManager", "ClientRemoved",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gsd_session_manager_on_signal_inhibitor_added (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(o)",
                   arg_id));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gnome.SessionManager", "InhibitorAdded",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gsd_session_manager_on_signal_inhibitor_removed (
    GsdSessionManager *object,
    const gchar *arg_id)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("(o)",
                   arg_id));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gnome.SessionManager", "InhibitorRemoved",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gsd_session_manager_on_signal_session_running (
    GsdSessionManager *object)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("()"));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gnome.SessionManager", "SessionRunning",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void
_gsd_session_manager_on_signal_session_over (
    GsdSessionManager *object)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);

  GList      *connections, *l;
  GVariant   *signal_variant;
  connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));

  signal_variant = g_variant_ref_sink (g_variant_new ("()"));
  for (l = connections; l != NULL; l = l->next)
    {
      GDBusConnection *connection = l->data;
      g_dbus_connection_emit_signal (connection,
        NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.gnome.SessionManager", "SessionOver",
        signal_variant, NULL);
    }
  g_variant_unref (signal_variant);
  g_list_free_full (connections, g_object_unref);
}

static void gsd_session_manager_skeleton_iface_init (GsdSessionManagerIface *iface);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (GsdSessionManagerSkeleton, gsd_session_manager_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_ADD_PRIVATE (GsdSessionManagerSkeleton)
                         G_IMPLEMENT_INTERFACE (GSD_TYPE_SESSION_MANAGER, gsd_session_manager_skeleton_iface_init));

#else
G_DEFINE_TYPE_WITH_CODE (GsdSessionManagerSkeleton, gsd_session_manager_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_IMPLEMENT_INTERFACE (GSD_TYPE_SESSION_MANAGER, gsd_session_manager_skeleton_iface_init));

#endif
static void
gsd_session_manager_skeleton_finalize (GObject *object)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);
  guint n;
  for (n = 0; n < 3; n++)
    g_value_unset (&skeleton->priv->properties[n]);
  g_free (skeleton->priv->properties);
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
  if (skeleton->priv->changed_properties_idle_source != NULL)
    g_source_destroy (skeleton->priv->changed_properties_idle_source);
  g_main_context_unref (skeleton->priv->context);
  g_mutex_clear (&skeleton->priv->lock);
  G_OBJECT_CLASS (gsd_session_manager_skeleton_parent_class)->finalize (object);
}

static void
gsd_session_manager_skeleton_get_property (GObject      *object,
  guint         prop_id,
  GValue       *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);
  g_assert (prop_id != 0 && prop_id - 1 < 3);
  g_mutex_lock (&skeleton->priv->lock);
  g_value_copy (&skeleton->priv->properties[prop_id - 1], value);
  g_mutex_unlock (&skeleton->priv->lock);
}

static gboolean
_gsd_session_manager_emit_changed (gpointer user_data)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (user_data);
  GList *l;
  GVariantBuilder builder;
  GVariantBuilder invalidated_builder;
  guint num_changes;

  g_mutex_lock (&skeleton->priv->lock);
  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
  g_variant_builder_init (&invalidated_builder, G_VARIANT_TYPE ("as"));
  for (l = skeleton->priv->changed_properties, num_changes = 0; l != NULL; l = l->next)
    {
      ChangedProperty *cp = l->data;
      GVariant *variant;
      const GValue *cur_value;

      cur_value = &skeleton->priv->properties[cp->prop_id - 1];
      if (!_g_value_equal (cur_value, &cp->orig_value))
        {
          variant = g_dbus_gvalue_to_gvariant (cur_value, G_VARIANT_TYPE (cp->info->parent_struct.signature));
          g_variant_builder_add (&builder, "{sv}", cp->info->parent_struct.name, variant);
          g_variant_unref (variant);
          num_changes++;
        }
    }
  if (num_changes > 0)
    {
      GList *connections, *ll;
      GVariant *signal_variant;
      signal_variant = g_variant_ref_sink (g_variant_new ("(sa{sv}as)", "org.gnome.SessionManager",
                                           &builder, &invalidated_builder));
      connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));
      for (ll = connections; ll != NULL; ll = ll->next)
        {
          GDBusConnection *connection = ll->data;

          g_dbus_connection_emit_signal (connection,
                                         NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)),
                                         "org.freedesktop.DBus.Properties",
                                         "PropertiesChanged",
                                         signal_variant,
                                         NULL);
        }
      g_variant_unref (signal_variant);
      g_list_free_full (connections, g_object_unref);
    }
  else
    {
      g_variant_builder_clear (&builder);
      g_variant_builder_clear (&invalidated_builder);
    }
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
  skeleton->priv->changed_properties = NULL;
  skeleton->priv->changed_properties_idle_source = NULL;
  g_mutex_unlock (&skeleton->priv->lock);
  return FALSE;
}

static void
_gsd_session_manager_schedule_emit_changed (GsdSessionManagerSkeleton *skeleton, const _ExtendedGDBusPropertyInfo *info, guint prop_id, const GValue *orig_value)
{
  ChangedProperty *cp;
  GList *l;
  cp = NULL;
  for (l = skeleton->priv->changed_properties; l != NULL; l = l->next)
    {
      ChangedProperty *i_cp = l->data;
      if (i_cp->info == info)
        {
          cp = i_cp;
          break;
        }
    }
  if (cp == NULL)
    {
      cp = g_new0 (ChangedProperty, 1);
      cp->prop_id = prop_id;
      cp->info = info;
      skeleton->priv->changed_properties = g_list_prepend (skeleton->priv->changed_properties, cp);
      g_value_init (&cp->orig_value, G_VALUE_TYPE (orig_value));
      g_value_copy (orig_value, &cp->orig_value);
    }
}

static void
gsd_session_manager_skeleton_notify (GObject      *object,
  GParamSpec *pspec G_GNUC_UNUSED)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);
  g_mutex_lock (&skeleton->priv->lock);
  if (skeleton->priv->changed_properties != NULL &&
      skeleton->priv->changed_properties_idle_source == NULL)
    {
      skeleton->priv->changed_properties_idle_source = g_idle_source_new ();
      g_source_set_priority (skeleton->priv->changed_properties_idle_source, G_PRIORITY_DEFAULT);
      g_source_set_callback (skeleton->priv->changed_properties_idle_source, _gsd_session_manager_emit_changed, g_object_ref (skeleton), (GDestroyNotify) g_object_unref);
      g_source_set_name (skeleton->priv->changed_properties_idle_source, "[generated] _gsd_session_manager_emit_changed");
      g_source_attach (skeleton->priv->changed_properties_idle_source, skeleton->priv->context);
      g_source_unref (skeleton->priv->changed_properties_idle_source);
    }
  g_mutex_unlock (&skeleton->priv->lock);
}

static void
gsd_session_manager_skeleton_set_property (GObject      *object,
  guint         prop_id,
  const GValue *value,
  GParamSpec   *pspec)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);
  g_assert (prop_id != 0 && prop_id - 1 < 3);
  g_mutex_lock (&skeleton->priv->lock);
  g_object_freeze_notify (object);
  if (!_g_value_equal (value, &skeleton->priv->properties[prop_id - 1]))
    {
      if (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)) != NULL)
        _gsd_session_manager_schedule_emit_changed (skeleton, _gsd_session_manager_property_info_pointers[prop_id - 1], prop_id, &skeleton->priv->properties[prop_id - 1]);
      g_value_copy (value, &skeleton->priv->properties[prop_id - 1]);
      g_object_notify_by_pspec (object, pspec);
    }
  g_mutex_unlock (&skeleton->priv->lock);
  g_object_thaw_notify (object);
}

static void
gsd_session_manager_skeleton_init (GsdSessionManagerSkeleton *skeleton)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  skeleton->priv = gsd_session_manager_skeleton_get_instance_private (skeleton);
#else
  skeleton->priv = G_TYPE_INSTANCE_GET_PRIVATE (skeleton, GSD_TYPE_SESSION_MANAGER_SKELETON, GsdSessionManagerSkeletonPrivate);
#endif

  g_mutex_init (&skeleton->priv->lock);
  skeleton->priv->context = g_main_context_ref_thread_default ();
  skeleton->priv->properties = g_new0 (GValue, 3);
  g_value_init (&skeleton->priv->properties[0], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[1], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[2], G_TYPE_UINT);
}

static const gchar *
gsd_session_manager_skeleton_get_session_name (GsdSessionManager *object)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_string (&(skeleton->priv->properties[0]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
gsd_session_manager_skeleton_get_session_is_active (GsdSessionManager *object)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_boolean (&(skeleton->priv->properties[1]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
gsd_session_manager_skeleton_get_inhibited_actions (GsdSessionManager *object)
{
  GsdSessionManagerSkeleton *skeleton = GSD_SESSION_MANAGER_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_value_get_uint (&(skeleton->priv->properties[2]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static void
gsd_session_manager_skeleton_class_init (GsdSessionManagerSkeletonClass *klass)
{
  GObjectClass *gobject_class;
  GDBusInterfaceSkeletonClass *skeleton_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize = gsd_session_manager_skeleton_finalize;
  gobject_class->get_property = gsd_session_manager_skeleton_get_property;
  gobject_class->set_property = gsd_session_manager_skeleton_set_property;
  gobject_class->notify       = gsd_session_manager_skeleton_notify;


  gsd_session_manager_override_properties (gobject_class, 1);

  skeleton_class = G_DBUS_INTERFACE_SKELETON_CLASS (klass);
  skeleton_class->get_info = gsd_session_manager_skeleton_dbus_interface_get_info;
  skeleton_class->get_properties = gsd_session_manager_skeleton_dbus_interface_get_properties;
  skeleton_class->flush = gsd_session_manager_skeleton_dbus_interface_flush;
  skeleton_class->get_vtable = gsd_session_manager_skeleton_dbus_interface_get_vtable;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (GsdSessionManagerSkeletonPrivate));
#endif
}

static void
gsd_session_manager_skeleton_iface_init (GsdSessionManagerIface *iface)
{
  iface->client_added = _gsd_session_manager_on_signal_client_added;
  iface->client_removed = _gsd_session_manager_on_signal_client_removed;
  iface->inhibitor_added = _gsd_session_manager_on_signal_inhibitor_added;
  iface->inhibitor_removed = _gsd_session_manager_on_signal_inhibitor_removed;
  iface->session_running = _gsd_session_manager_on_signal_session_running;
  iface->session_over = _gsd_session_manager_on_signal_session_over;
  iface->get_session_name = gsd_session_manager_skeleton_get_session_name;
  iface->get_session_is_active = gsd_session_manager_skeleton_get_session_is_active;
  iface->get_inhibited_actions = gsd_session_manager_skeleton_get_inhibited_actions;
}

/**
 * gsd_session_manager_skeleton_new:
 *
 * Creates a skeleton object for the D-Bus interface <link linkend="gdbus-interface-org-gnome-SessionManager.top_of_page">org.gnome.SessionManager</link>.
 *
 * Returns: (transfer full) (type GsdSessionManagerSkeleton): The skeleton object.
 */
GsdSessionManager *
gsd_session_manager_skeleton_new (void)
{
  return GSD_SESSION_MANAGER (g_object_new (GSD_TYPE_SESSION_MANAGER_SKELETON, NULL));
}

